{
	"name" : "Sales Management - Reporting",
	"version" : "1.0",
	"author" : "Tiny",
	"website" : "http://tinyerp.com/module_sale.html",
	"depends" : ["sale"],
	"category" : "Generic Modules/Sales & Purchases",
	"init_xml" : [],
	"demo_xml" : [],
	"update_xml" : ["report_sale_view.xml","report_sale_graph.xml"],
	"active": False,
	"installable": True
}
